def recuring_fractionto_decimal(divident: int, diviser: int) -> float:
    c, q, r = 0.0, 0, 0
    if(diviser%10 == 9):
        diviser= diviser
    elif(diviser%10 == 3):
        diviser= 3*diviser 
        divident= 3*divident
    elif(diviser%10 == 7):
        diviser= 7*diviser
        divident= 7*divident
    elif(diviser%10 == 1):
        diviser= 9*diviser
        divident= 9*divident
    else:
        print("Error: Not a recurring decimal.")
        exit(0)
    
    op= diviser/10 +1
    for i in range(0, 6):
        q= divident//op; r= divident%op
        divident= r*10 +q
        c= c+ q*(10**(-(i+1)))
    
    return round(c,6)


from math import floor, log10

def square_ending5(a: int) -> int:
    a= int(a)
    if(a%10 == 5):
        c= (a//10)*((a//10)+1)*100 +25
    else:
        print("Error: The last digit of the number should be 5.")
        exit(0)
    
    return c

def square_near_powerof10(a: int) -> int:
    a= int(a)
    n= floor(log10(abs(a))) + 1
    d1= a-(10**n); d2= a-(10**(n-1))
    c= d2 if abs(d1)>abs(d2) else d1
    n= n-1 if abs(d1)>abs(d2) else n
    c= (a+c)*(10**n) + c*c
    return c

def square_under100(a: int) -> int:
    a= int(a)
    n= floor(log10(abs(a))) + 1
    if(n==1 or n==2):
        b= a%10;  a//=10
        c= a*a*100+ 2*a*b*10 + b*b
    
    else:
        print("Error: Number should be less than 100.");  exit(0)
    
    return c

def square_from100_to1000(a: int) -> int:
    a= int(a)
    n= floor(log10(abs(a))) + 1
    if(n==3):
        c= a%10;  a//=10; b= a%10; a//=10
        result= a*a*10000+ 2*a*b*1000 + (b*b + 2*a*c)*100+ 2*b*c*10+ c*c
    
    else:
        print("Error: Number should be between 100 and 1000.");  exit(0)
    
    return result

def perfect_sqrt_under_sqof100(a: int) -> int:
    a= int(a)
    c=0; b= a%10
    for i in range(100):
        if((i*10)**2 <= a ):
            if(a <= ((i+1)*10)**2):
                c= i*10; break
    
    d1= a- ((i*10)**2); d2= (((i+1)*10)**2)- a
    if(b==0): b=0

    elif(b==1): b= 1 if (d2>d1) else 9

    elif(b==4): b= 2 if (d2>d1) else 8

    elif(b==6): b= 4 if (d2>d1) else 6
    
    elif(b==9): b= 3 if (d2>d1) else 7
    
    elif(b==5): b= 5
    
    else:
        print("Error: Not a perfect square."); exit(0)
    
    return (c+b)


def divisibility_under10(a: int, b: int):
    i=0
    if(b==2 or b==3 or b==4 or b==5 or b==6 or b==8 or b==9):
        if(b==2 and a%2==0): i=1
        
        elif(b==3):
            sum=0
            while(a!=0):
                sum+=a%10
                a//=10
            if(sum%3==0): i=1
        
        elif(b==4 and (a%100)%4==0): i=1

        elif(b==5 and (a%10==5 or a%10==0)): i=1
        elif(b==6 and a%2==0):
            sum=0
            while(a!=0):
                sum+=a%10
                a//=10
            if(sum%3==0): i=1
        
        elif(b==8 and (a%10000)%8==0): i=1
        
        elif(b==9):
            sum=0
            while(a!=0):
                sum+=a%10
                a//=10
            if(sum%9==0): i=1
    
    else:
        print("Error: The divisibility test is only applicable with 2,3,4,5,6,8 and 9.")
        exit(0)

    if(i==1):
        print("The number is divisible.")
    else:
        print("The number is not divisible.")
    


"""Top-level package for vedicpy."""

__author__ = 'Utkarsh Mishra'
__email__ = 'utkarsh.um07@gmail.com'
__version__ = '0.0.1'

from vedicpy import compliment
from vedicpy import cube_cuberoot
from vedicpy import divisibility
from vedicpy import division
from vedicpy import multiply
from vedicpy import recurring
from vedicpy import sq_sqrt


def division_by9(a: int):
    summ = i = q = 0
    arr=[]
    while(a!=0):
        b, a = a%10, a//10
        summ+=b
        arr.append(b)
    
    if(summ>=9):
        for j in range(2,8):
            if(summ<(9*j)):
                i= j-1
                r= summ- (9*(j-1))
                break
            
    else:
        r= summ
    
    b=0
    for j in range(len(arr)-1, 0, -1):
        b+= arr[j]
        q+= b*(10**(j-1))
    q+=i
    print("The quotent is: ",q)
    print("The reminder is: ",r)


import setuptools

setuptools.setup(
    name="vedicpy", 
    version="0.0.7",
    author="Utkarsh Mishra",
    author_email="utkarsh.um07@gmail.com",
    description="A Python Package for Vedic Mathematics",
    long_description_content_type="text/markdown",
    url="https://github.com/utkarsh0702/vedicpy",
    packages=setuptools.find_packages(exclude=['tests*']),
    test_suite='tests',
    license="BSD",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
    ],
    keyword="vedic python",
    python_requires='>=3.6',
)




from math import floor, log10

def cube_a_number(a: int) -> int:
    n = floor(log10(abs(a))) + 1 
    d1, d2= a-(10**n), a-(10**(n-1))
    d= d2 if abs(d1)>abs(d2) else d1
    b= 10**(n-1) if abs(d1)>abs(d2) else 10**n
    ne= d+ 2*d
    if(d<0):
        for i in range(1,11):
            if(abs(d*d*d)<(i*b)):
                c= (a+2*d)*(b**2) + (ne*d-i)*b + (i*b + d*d*d)
                break
    else:
        c= (a+2*d)*(b**2) + ne*d*b + d*d*d
    
    return c

def cube_2digit_number(a: int) -> int:
    a= int(a)
    n= floor(log10(abs(a))) + 1
    if(n==2 or n==1):
        b, a = a%10, a//10
        c= (a**3)*1000 + 3*(a**2)*b*100 + 3*a*(b**2)*10 + b**3
    
    else:
        print("Error: Input should be a 2 digit number only.")
        exit(0)

    return c

def cuberoot_under_1000000(a: int) -> int:
    a= int(a)
    c, a = a%10, a//10
    if(c==2): c=8
    elif(c==3): c=7
    elif(c==7): c=3
    elif(c==8): c=2
    a//=100
    for i in range(1,11):
        if(a<(i**3)):
            c+= (i-1)*10
            break
    
    return c